@@ -1,20 +1,30 @@
 # pylint:disable=C0111
 import os
+from typing import AnyStr, IO, Union
 
 import maxminddb.reader
 
 try:
     import maxminddb.extension
 except ImportError:
-    maxminddb.extension = None
+    maxminddb.extension = None  # type: ignore
 
-from maxminddb.const import (MODE_AUTO, MODE_MMAP, MODE_MMAP_EXT, MODE_FILE,
-                             MODE_MEMORY, MODE_FD)
+from maxminddb.const import (
+    MODE_AUTO,
+    MODE_MMAP,
+    MODE_MMAP_EXT,
+    MODE_FILE,
+    MODE_MEMORY,
+    MODE_FD,
+)
 from maxminddb.decoder import InvalidDatabaseError
+from maxminddb.reader import Reader as PyReader
 
 
-def open_database(database, mode=MODE_AUTO):
-    """Open a Maxmind DB database
+def open_database(
+    database: Union[AnyStr, int, os.PathLike, IO], mode: int = MODE_AUTO
+) -> Union[PyReader, "maxminddb.extension.Reader"]:
+    """Open a MaxMind DB database
 
     Arguments:
         database -- A path to a valid MaxMind DB file such as a GeoIP2 database
@@ -29,17 +39,16 @@ def open_database(database, mode=MODE_AUTO):
             * MODE_AUTO - tries MODE_MMAP_EXT, MODE_MMAP, MODE_FILE in that
                           order. Default mode.
     """
-    has_extension = maxminddb.extension and hasattr(maxminddb.extension,
-                                                    'Reader')
+    has_extension = maxminddb.extension and hasattr(maxminddb.extension, "Reader")
     if (mode == MODE_AUTO and has_extension) or mode == MODE_MMAP_EXT:
         if not has_extension:
             raise ValueError(
                 "MODE_MMAP_EXT requires the maxminddb.extension module to be available"
             )
         return maxminddb.extension.Reader(database)
-    elif mode in (MODE_AUTO, MODE_MMAP, MODE_FILE, MODE_MEMORY, MODE_FD):
-        return maxminddb.reader.Reader(database, mode)
-    raise ValueError('Unsupported open mode: {0}'.format(mode))
+    if mode in (MODE_AUTO, MODE_MMAP, MODE_FILE, MODE_MEMORY, MODE_FD):
+        return PyReader(database, mode)
+    raise ValueError("Unsupported open mode: {0}".format(mode))
 
 
 def Reader(database):  # pylint: disable=invalid-name
@@ -47,8 +56,8 @@ def Reader(database):  # pylint: disable=invalid-name
     return open_database(database)
 
 
-__title__ = 'maxminddb'
-__version__ = '1.4.0'
-__author__ = 'Gregory Oschwald'
-__license__ = 'Apache License, Version 2.0'
-__copyright__ = 'Copyright 2013-2018 Maxmind, Inc.'
+__title__ = "maxminddb"
+__version__ = "2.0.0"
+__author__ = "Gregory Oschwald"
+__license__ = "Apache License, Version 2.0"
+__copyright__ = "Copyright 2013-2020 MaxMind, Inc."
